pub enum TransitionIntent {
RequestMedicalReview,
ApplyCapacityDecision,
ConfirmAcceptedOffer,
CancelReservation,
RejectByPolicy,
CompleteCheckout,
}Expand description
Intended reservation transition requested by a workflow before policy and review checks are applied.
Variants
RequestMedicalReview
Request medical review workflow state, command, or review outcome.
ApplyCapacityDecision
Apply capacity decision workflow state, command, or review outcome.
ConfirmAcceptedOffer
Confirm accepted offer workflow state, command, or review outcome.
CancelReservation
Cancel reservation workflow state, command, or review outcome.
RejectByPolicy
Reject by policy workflow state, command, or review outcome.
CompleteCheckout
Complete checkout workflow state, command, or review outcome.